==================
Python-DataCatalog
==================

.. image:: https://badge.fury.io/py/datacatalog.svg
    :target: http://badge.fury.io/py/datacatalog

.. image:: https://travis-ci.org/SD2E/python-datacatalog.svg?branch=master
    :target: https://travis-ci.org/SD2E/python-datacatalog

.. image:: https://readthedocs.org/projects/sd2-data-catalog/badge/?version=latest
    :target: https://sd2-data-catalog.readthedocs.io/

.. image:: https://img.shields.io/pypi/l/Django.svg
    :target: https://travis-ci.org/SD2E/python-datacatalog/master/LICENSE

**Python package implementing core Data Catalog business logic***

Software projects using this package:

- https://github.com/SD2E/pipeline-jobs-manager
- https://github.com/SD2E/pipelines-manager
- https://github.com/SD2E/demo-jobs-enabled-reactor
- https://github.com/SD2E/demo-jobs-enabled-reactor

Usage
=====

_More information is forthcoming._
